@@ -4,7 +4,6 @@ package tproxy
 
 import (
 	"errors"
-	"github.com/tobyxdd/hysteria/pkg/acl"
 	"github.com/tobyxdd/hysteria/pkg/core"
 	"github.com/tobyxdd/hysteria/pkg/transport"
 	"net"
@@ -16,7 +15,6 @@ var ErrTimeout = errors.New("inactivity timeout")
 type UDPTProxy struct{}
 
 func NewUDPTProxy(hyClient *core.Client, transport transport.Transport, listen string, timeout time.Duration,
-	aclEngine *acl.Engine,
 	connFunc func(addr net.Addr), errorFunc func(addr net.Addr, err error)) (*UDPTProxy, error) {
 	return nil, errors.New("not supported on the current system")
 }
